## Stand Alone Script for the B2B observation imaging                      
## (Customized for uid://A002/Xc660ef/X2d26, VY CMa Band9 B2B)           
## Script to image the B2B B4 to B9
## VY CMa testing data 
## NOTE this is not an SV dataset

## This is the updated script and uses 'tclean'
## for compatability with CASA 5.6.1-8 - in the paper
## CASA 5.4.0 was used for imaging.
## Selfcal is made and continuum and cube images
## note pbcorrection is not made but can be done
## using impbcor

## Cleaning is INTERACTIVE ##

### Hardcoded script Final Version
### Yoshiharu Asaki JAO & Luke Maud ESO
### For further information please contact:
### yasaki@alma.cl   JAO/NAOJ
### a.m.s.richards@manchester.ac.uk 
### lmaud@eso.org   ESO
###
### If using these data please reference:
### Asaki et al 2020 ApJS 247 23
### and B2B papers therein and published thereafter



import sys

from glob import glob
from scipy import constants
from scipy import stats
import warnings



thesteps = []
step_title = {0: 'Save flags and plotms',
#### Self-calibration
              1: 'First continuum image for phase-only gaincal (phase self-cal)',
              2: 'Second continuum image for amp-only gaincal (amp self-cal)',
              3: 'H2O maser imaging: initial calibration using the continuum self-cal solution',
              4: 'Bright single H2O maser channel (spw=0:1021) imaging',
              5: 'H2O maser phase-only gaincal (phase self-cal (1))',
              6: 'H2O maser amp-only gaincal (amp self-cal (1))',
              7: 'H2O maser phase-only gaincal (phase self-cal (2))',
              8: 'H2O maser amp-only gaincal (amp self-cal (2))',
#### Continuum imaging
              9: 'Final continuum image (robustness parameter = 2)',
              10: 'Continuum Subtraction from the line visibility',
#### H2O maser cube
              11: 'Image cube: Water Maser (Spw0, no channel averaging)',
#### SiO maser cube
              12: 'Image cube: 676 GHz 29SiO J=16-15 v=2 maser',
              13: 'Make the fits images'}

if 'applyonly' not in globals(): applyonly = True

try:
  print 'List of steps to be executed ...', mysteps
  thesteps = mysteps
except:
  print 'global variable mysteps not set.'
if (thesteps==[]):
  # this is hardcoded to run all (selected) steps
  thesteps = [0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24]
  print 'Executing all steps: ', thesteps

import re
import os
import casadef

if applyonly != True: es = aU.stuffForScienceDataReduction() 

if re.search('^5.6.1', casadef.casa_version) == None:
 sys.exit('ERROR: PLEASE USE THE SAME VERSION OF CASA THAT YOU USED FOR GENERATING THE SCRIPT: 5.6.1')

###################################################
## USER set input for these test scripts

refant  = 'DV07'

contchans='0,1:9~46;56~110,2:0~50;69~118,3,4:1~57;68~118,5,6,7'
contchansline='0:0~850;1200~1919,1:0~650;1110~1540,2:1~850;1180~1400;1640~1919,3:0~420;680~820;1050~1919,4,5:0~850;1100~1919'

# tCLEAN masks
mask_cont=['circle[[1074pix,1074pix],140pix]', 'circle[[700pix,850pix],150pix]', 'circle[[850pix,900pix],150pix]', 'circle[[540pix,800pix],60pix]', 'circle[[950pix,950pix],100pix]', 'circle[[1000pix,1200pix],120pix]', 'circle[[850pix,1350pix],140pix]', 'circle[[1150pix,900pix],120pix]']
mask_line_H2O=['circle[[1024pix,1024pix],230pix]', 'circle[[700pix,850pix],150pix]', 'circle[[850pix,900pix],150pix]', 'circle[[950pix,950pix],100pix]']
mask_line_SiO=['circle[[256pix,260pix],60pix]']
inter=True

# boxes for image statistics
rbox='10,10,1000,100'
pbox='824,824,1223,1223'

# line box
r5box='10,10,1000,100'
p5box='824,824,1223,1223'


###################################################
#
#  Data reduction steps
#
###################################################

#####################################
#
# Save flags before self-cal and plotms continuum
#
#####################################

mystep = 0
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  flagdata(vis = 'vycma.cont.ms',
      mode = 'manual',
      scan = '22',
      spw = '0:119',
      flagbackup = False)

  flagmanager(vis = 'vycma.cont.ms',
    mode = 'save',
    versionname = 'BeforeSelfCal')

  flagmanager(vis = 'vycma.line.ms',
    mode = 'save',
    versionname = 'BeforeSelfCal')

  os.system('rm -rf vycma.cont.ms.listobs')
  listobs(vis = 'vycma.cont.ms',
          overwrite=True,
          listfile='vycma.cont.ms.listobs')

  os.system('rm -rf vycma.line.ms.listobs')
  listobs(vis = 'vycma.line.ms',
          overwrite=True,
          listfile='vycma.line.ms.listobs')

  plotms(vis = 'vycma.cont.ms',
         xaxis='channel',
         yaxis='amp',
         iteraxis='spw',
         avgtime='999999',
#         uvrange='1~3000', #optional
#         avgbaseline=True, #optional
         avgscan=True)


#####################################
#
# First continuum image for phase-only gaincal (phase self-cal)
# Continuum image 0 (robustness parameter = 2)
#
#####################################

mystep = 1
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf vycma.cont_0.clean*')
  tclean(vis='vycma.cont.ms',
         field='VY*', 
         spw=contchans,
         antenna='!DV14,DV25,PM01,PM03',
         specmode='mfs',
         mask=mask_cont,
         imagename='vycma.cont_0.clean', 
         threshold='0mJy', 
         niter=1500, 
         imsize=2048, 
         cell='0.0010arcsec',
         weighting='briggs', 
         robust=2, 
         datacolumn='data',
         interactive=inter)

  rms=imstat(imagename='vycma.cont_0.clean.image', box=rbox)['rms'][0]
  peak=imstat(imagename='vycma.cont_0.clean.image', box=pbox)['max'][0]
  print 'vycma.cont_0.clean.image: Peak %7.3f mJy/bm, rms  %6.3f mJy, S/N %5.1f' % (peak*1000., rms*1000., peak/rms)
         
# imfit
# ra:    07:22:58.3261 +/- 0.000053 s (0.00071 arcsec)
# dec:  -25.46.03.0355 +/- 0.000873 arcsec
# adjust future imsizes and maybe shift
# measure absolute position

#####################################
# Phase-only gaincal
#####################################

  ft(vis='vycma.cont.ms', 
     model='vycma.cont_0.clean.model',
     usescratch=True)

  os.system('rm -rf vycma.cont_p1*')
  gaincal(vis='vycma.cont.ms', 
          caltable='vycma.cont_p1', 
          spw=contchans,
          solint='inf', 
          calmode='p',
          refant=refant, 
          gaintype='G', 
          minsnr=1.0)

  if applyonly != True: es.checkCalTable('vycma.cont_p1', msName='vycma.cont.ms', interactive=False)

#####################################
# Solutioion application and visibility plot to confirm the result
#####################################

  flagmanager(vis='vycma.cont.ms',
              mode='save',
              versionname='beforeapplycal1')

  applycal(vis='vycma.cont.ms',
           gaintable=['vycma.cont_p1'],
           interp='nearest',
           calwt=False,
           applymode='calonly',
           flagbackup=False)

  plotms(vis = 'vycma.cont.ms',
         xaxis='uvdist',
         yaxis='amp',
         ydatacolumn='corrected',
         iteraxis='spw',
         avgtime='999999',
         avgchannel='128',
         coloraxis='spw')


#####################################
#
# Second continuum image for amp-only gaincal (amp self-cal)
# (robustness parameter = 2)
#
#####################################
  
mystep = 2
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf vycma.cont_p1.clean*')
  tclean(vis='vycma.cont.ms',
         field='VY*', 
         spw=contchans,
         specmode='mfs',
         deconvolver='mtmfs',
         nterms=2,
         scales=[0,5,10,15],
         imagename='vycma.cont_p1.clean', 
         mask=mask_cont,
         threshold='0mJy', 
         niter=2000, 
         imsize=2048, 
         cell='0.0010arcsec',
         weighting='briggs', 
         robust=2, 
         interactive=inter)

  rms=imstat(imagename='vycma.cont_p1.clean.image.tt0', box=rbox)['rms'][0]
  peak=imstat(imagename='vycma.cont_p1.clean.image.tt0', box=pbox)['max'][0]
  print 'vycma.cont_p1.clean.image.tt0: Peak %7.3f mJy/bm, rms  %6.3f mJy, S/N %5.1f' % (peak*1000., rms*1000., peak/rms)

#####################################
# split out with applied cal to make sure all data seen by gaincal
#####################################

  os.system('rm -rf vycma.cont_p1.ms')
  split(vis='vycma.cont.ms',
      outputvis='vycma.cont_p1.ms',
      datacolumn='corrected')

  ft(vis='vycma.cont_p1.ms', 
     nterms=2,
     model=['vycma.cont_p1.clean.model.tt0','vycma.cont_p1.clean.model.tt1'],
     usescratch=True)

#####################################
# try averaging pols
#####################################

  os.system('rm -rf vycma.cont_a1*')
  gaincal(vis='vycma.cont_p1.ms', 
          caltable='vycma.cont_a1', 
          spw=contchans, 
          solint='inf',
          calmode='a',
          refant=refant, 
          solnorm=True,
          gaintype='T', 
          minsnr=1.0)

  if applyonly != True: es.checkCalTable('vycma.cont_a1', msName='vycma.cont_p1.ms', interactive=False)


#####################################
#
# H2O maser imaging: initial calibration using the continuum self-cal solution
#
#####################################

mystep = 3
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  applycal(vis='vycma.line.ms',
           gaintable=['vycma.cont_p1','vycma.cont_a1'],
           interp='nearest',
           calwt=False,
           applymode='calonly')

  plotms(vis = 'vycma.line.ms',
         xaxis='channel',
         yaxis='amp',
         ydatacolumn='corrected',
         uvrange='1~1000', #optional
         iteraxis='spw',
         avgtime='999999',
         avgscan=True)
        
# split out line data with calibration

  os.system('rm -rf vycma.linecal.ms*')
  split(vis='vycma.line.ms',
        datacolumn='corrected',
        outputvis='vycma.linecal.ms')

# Flag some end channels

  flagmanager(vis = 'vycma.linecal.ms',
              mode='save',
              versionname='pre_linecalflag')

  flagdata(vis = 'vycma.linecal.ms',
           mode='manual',
           spw='1:0,3:0,4:1919,5:0')


#####################################
#
# Bright single H2O maser channel (spw=0:1021) imaging
#
#####################################

mystep = 4
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

# Image channel  (NB also continuum)

  os.system('rm -rf vycma.line_spw0_1021.clean*')
  tclean(vis='vycma.linecal.ms',
         field='VY*', 
         spw='0',
         start=1021,
         nchan=1,
         specmode='cube',
         outframe='lsrk',
         imagename='vycma.line_spw0_1021.clean', 
         threshold='0mJy',
         niter=2000, 
         imsize=2048, 
         mask=mask_line_H2O,
         cell='0.0010arcsec',
         weighting='briggs', 
         robust=2, 
         interactive=inter)

  rms=imstat(imagename='vycma.line_spw0_1021.clean.image', box=r5box)['rms'][0]
  peak=imstat(imagename='vycma.line_spw0_1021.clean.image', box=p5box)['max'][0]
  print 'vycma.line_spw0_1021.clean.image: Peak %7.3f Jy/bm, rms  %6.3f Jy, S/N %5.1f' % (peak, rms, peak/rms)


#####################################
#
# H2O maser phase-only gaincal (phase self-cal (1))
#
#####################################

mystep = 5
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  ft(vis='vycma.linecal.ms', 
     model='vycma.line_spw0_1021.clean.model',
     spw='0:1021',
     usescratch=True)

  os.system('rm -rf vycma.line_p1')
  gaincal(vis='vycma.linecal.ms', 
          caltable='vycma.line_p1', 
          spw='0:1021',
          solint='16s', 
          calmode='p',
          refant=refant, 
          gaintype='G', 
          minsnr=1.0)

  if applyonly != True: es.checkCalTable('vycma.line_p1', msName='vycma.linecal.ms', interactive=False)

  flagmanager(vis='vycma.linecal.ms',
              mode='save',
              versionname='beforeapplycal1')

  applycal(vis='vycma.linecal.ms',
           gaintable=['vycma.line_p1'],
           interp='nearest',
           spw='0:1021',
           calwt=False,
           applymode='calonly',
           flagbackup=False)

  plotms(vis = 'vycma.linecal.ms',
         xaxis='uvdist',
         yaxis='amp',
         ydatacolumn='corrected',
         spw='0:1021',
         avgtime='999999',
         avgchannel='128',
         coloraxis='antenna2')
  

#####################################
#
# H2O maser amp-only gaincal (amp self-cal (1))
#
#####################################

mystep = 6
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

# Image channel  (NB also continuum)

  os.system('rm -rf vycma.line_p1.clean*')
  tclean(vis='vycma.linecal.ms',
         field='VY*', 
         spw='0',
         antenna='!DV25', # actually makes negligible difference
         start=1021,
         nchan=1,
         specmode='cube',
         outframe='lsrk',
         imagename='vycma.line_p1.clean', 
         threshold='0mJy',
         niter=2000, 
         imsize=2048, 
         cell='0.0010arcsec',
         weighting='briggs', 
         mask=mask_line_H2O,
         robust=2, 
         interactive=inter)

  rms=imstat(imagename='vycma.line_p1.clean.image', box=r5box)['rms'][0]
  peak=imstat(imagename='vycma.line_p1.clean.image', box=p5box)['max'][0]
  print 'vycma.line_p1.clean.image: Peak %7.3f Jy/bm, rms  %6.3f Jy, S/N %5.1f' % (peak, rms, peak/rms)

  ft(vis='vycma.linecal.ms', 
     model=['vycma.line_p1.clean.model'],
     spw='0:1021',
     usescratch=True)

# try averaging pols#
  os.system('rm -rf vycma.line_a1')
  gaincal(vis='vycma.linecal.ms', 
          caltable='vycma.line_a1', 
          gaintable='vycma.line_p1',
          spw='0:1021',
          solint='inf',
          calmode='a',
          refant=refant, 
          solnorm=True,
          gaintype='T', 
          minsnr=1.0)

  if applyonly != True: es.checkCalTable('vycma.line_a1', msName='vycma.linecal.ms', interactive=False)

  applycal(vis='vycma.linecal.ms',
           gaintable=['vycma.line_p1','vycma.line_a1'],
           spw='0:1021',
           interp='nearest',
           calwt=False,
           applymode='calonly',
           flagbackup=False)


#####################################
#
# H2O maser phase-only gaincal (phase self-cal (2))
#
#####################################

mystep = 7
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

# Image channel  (NB also continuum)
  os.system('rm -rf vycma.line_ap1.clean*')
  tclean(vis='vycma.linecal.ms',
         field='VY*', 
         spw='0',
         start=1021,
         nchan=1,
         specmode='cube',
         outframe='lsrk',
         imagename='vycma.line_ap1.clean', 
         threshold='0mJy',
         niter=2000, 
         imsize=2048, 
         mask=mask_line_H2O,
         cell='0.0010arcsec',
         weighting='briggs', 
         robust=2, 
         interactive=inter)

  rms=imstat(imagename='vycma.line_ap1.clean.image', box=r5box)['rms'][0]
  peak=imstat(imagename='vycma.line_ap1.clean.image', box=p5box)['max'][0]
  print 'vycma.line_ap1.clean.image: Peak %7.3f Jy/bm, rms  %6.3f Jy, S/N %5.1f' % (peak, rms, peak/rms)

#####################################
# Phase-only gaincaly (self-cal)
#####################################

  ft(vis='vycma.linecal.ms', 
     model='vycma.line_ap1.clean.model',
     spw='0:1021',
     usescratch=True)

  os.system('rm -rf vycma.line_p2')
  gaincal(vis='vycma.linecal.ms', 
          caltable='vycma.line_p2',
          gaintable=['vycma.line_p1','vycma.line_a1'],
          spw='0:1021',
          solint='int', 
          calmode='p',
          refant=refant, 
          gaintype='G', 
          minsnr=1.0)
  if applyonly != True: es.checkCalTable('vycma.line_p2', msName='vycma.linecal.ms', interactive=False)

  flagmanager(vis='vycma.linecal.ms',
              mode='save',
              versionname='beforeapplycal3')

  applycal(vis='vycma.linecal.ms',
           gaintable=['vycma.line_p2','vycma.line_p1','vycma.line_a1'],
           spw='0:1021',
           interp='nearest',
           calwt=False,
           applymode='calonly', 
           flagbackup=False)


#####################################
#
# H2O maser amp-only gaincal (amp self-cal (2))
#
#####################################

mystep = 8
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf vycma.line_ap2.clean*')
  tclean(vis='vycma.linecal.ms',
         field='VY*', 
         spw='0',
         start=1021,
         nchan=1,
         specmode='cube',
         outframe='lsrk',
         imagename='vycma.line_ap2.clean', 
         threshold='0mJy',
         niter=2000, 
         imsize=2048, 
         cell='0.0010arcsec',
         mask=mask_line_H2O,
         weighting='briggs', 
         robust=2, 
         interactive=inter)

  rms=imstat(imagename='vycma.line_ap2.clean.image', box=rbox)['rms'][0]
  peak=imstat(imagename='vycma.line_ap2.clean.image', box=pbox)['max'][0]
  print 'vycma.line_ap2.clean.image: Peak %7.3f Jy/bm, rms  %6.3f Jy, S/N %5.1f' % (peak, rms, peak/rms)

#####################################
# Amp-only gaincal (self-cal)
#####################################

  ft(vis='vycma.linecal.ms', 
     model=['vycma.line_ap2.clean.model'],
     spw='0:1021',
     usescratch=True)

###################
# try averaging pols#
###################

  os.system('rm -rf vycma.line_a2')
  gaincal(vis='vycma.linecal.ms', 
          caltable='vycma.line_a2', 
          gaintable=['vycma.line_p2','vycma.line_p1','vycma.line_a1'],
          spw='0:1021',
          solint='16s',
          calmode='a',
          refant=refant, 
          gaintype='T', 
          minsnr=1.0)

  if applyonly != True: es.checkCalTable('vycma.line_a2', msName='vycma.linecal.ms', interactive=False)


#####################################
#
# Final continuum image
# (robustness parameter = 2)
#
#####################################

mystep = 9
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  applycal(vis='vycma.cont.ms',
           gaintable=['vycma.cont_p1','vycma.cont_a1','vycma.line_p1','vycma.line_a1','vycma.line_p2','vycma.line_a2'],
           interp='nearest',
           spw='0~7',
           spwmap=[[],[],[0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0],[0,0,0,0,0,0,0,0]],
           calwt=False,
           applymode='calonly')

  os.system('rm -rf VYCMa_sci.spw29_31_33_35_37_39_41_43.cont.I.manual-selfcal-robust.*')
  tclean(vis='vycma.cont.ms',
         field='VY*', 
         spw=contchans,
         specmode='mfs', 
         imagename='VYCMa_sci.spw29_31_33_35_37_39_41_43.cont.I.manual-selfcal-robust', 
         threshold='0mJy',
         deconvolver='mtmfs',
         nterms=2,
         scales=[0,5,10,15],
         niter=2000,
         mask=mask_cont,
         imsize=2048, 
         cell='0.0010arcsec',
         weighting='briggs', 
         robust=2, 
         interactive=inter)

  rms=imstat(imagename='VYCMa_sci.spw29_31_33_35_37_39_41_43.cont.I.manual-selfcal-robust.image.tt0', box=rbox)['rms'][0]
  peak=imstat(imagename='VYCMa_sci.spw29_31_33_35_37_39_41_43.cont.I.manual-selfcal-robust.image.tt0', box=pbox)['max'][0]
  print 'VYCMa_sci.spw29_31_33_35_37_39_41_43.cont.I.manual-selfcal-robust.image.tt0: Peak %7.3f mJy/bm, rms  %6.3f mJy, S/N %5.1f' % (peak*1000., rms*1000., peak/rms)


#####################################
#
# Continuum subtraction
#
#####################################

mystep = 10
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  os.system('rm -rf vycma.linecal.ms.contsub*')
  mstransform(vis='vycma.linecal.ms',
            outputvis='vycma.linecal.ms.contsub',
            douvcontsub=True,
            field='VY*',
            fitorder=1,
            fitspw=contchansline,
            niter=50)


#####################################
#
# Image cube: 658 GHz water maser
# (0.5 km/s velocity resolution)
#
#####################################

mystep = 11
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  # referencing the original dataset is spw 33
  # in the split dataset this is spw 2
  # as Spw 0 and 1 are not included with the vycma.line measurement set, this is now reordered to spw 0 
  os.system('rm -rf VYCMa_sci.spw33.cube.I.manual-selfcal-H20-658GHz-robust.*')
  tclean(vis='vycma.linecal.ms.contsub',
         field='VY*', 
         spw='0',
         specmode='cube',
         start=985,
         nchan=128,
         restfreq='658.00655GHz',
         outframe='lsrk',
         imagename='VYCMa_sci.spw33.cube.I.manual-selfcal-H20-658GHz-robust',
         threshold='400mJy', # around water line 
         niter=350000, 
         imsize=2048, 
         cell='0.0010arcsec',
         weighting='briggs', 
         robust=0.5, 
         usemask='auto-multithresh',
         noisethreshold=4.5,
         sidelobethreshold=2.0,
         growiterations=20,
         chanchunks=2,
         interactive=inter)


#####################################
#
# Image cube: 676 GHz 29SiO J=16-15 v=2 maser
# (2 km/s velocity resolution)
#
#####################################

mystep = 12
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

  # referencing the original dataset is spw 39
  # in the split dataset this is spw 5
  # as Spw 0 and 1 are not included with the vycma.line measurement set, this is now reordered to spw 0 
  os.system('rm -rf VYCMa_sci.spw39.cube.I.manual-selfcal-29SiO-J16-15-676GHz-robust.*')
  tclean(vis='vycma.linecal.ms.contsub',
         field='VY*', 
         spw='3',
         specmode='cube',
#         restfreq='676.1321271GHz',  # CDMS
         restfreq='676.132183GHz',  # OT/Splatalogue
         start=420,
         nchan=64,
         width=4,
         outframe='lsrk',
         imagename='VYCMa_sci.spw39.cube.I.manual-selfcal-29SiO-J16-15-676GHz-robust', #
         threshold='100mJy',
         niter=200000, 
         imsize=512, 
         cell='0.0010arcsec',
         weighting='briggs', 
         robust=1.5, 
         interactive=inter)


##################################
#
# Make the fits images
#
##################################

mystep = 13
if(mystep in thesteps):
  casalog.post('Step '+str(mystep)+' '+step_title[mystep],'INFO')
  print 'Step ', mystep, step_title[mystep]

 

  myimagebase = 'VYCMa_sci.spw29_31_33_35_37_39_41_43.cont.I.manual-selfcal-robust.image.tt0'
  myfits = 'VYCMa_sci.spw29_31_33_35_37_39_41_43.cont.tt0.I.manual-selfcal-robust.image.fits'

  exportfits(imagename = myimagebase,
             fitsimage = myfits,
             overwrite = True
             )

 

  myimagebase = 'VYCMa_sci.spw33.cube.I.manual-selfcal-H20-658GHz-robust.image'
  myfits = 'VYCMa_sci.spw33.cube.I.manual-selfcal-H20-658GHz-robust.image.fits'

  exportfits(imagename = myimagebase,
             fitsimage = myfits,
             overwrite = True
             )

 
  myimagebase = 'VYCMa_sci.spw39.cube.I.manual-selfcal-29SiO-J16-15-676GHz-robust.image'
  myfits = 'VYCMa_sci.spw39.cube.I.manual-selfcal-29SiO-J16-15-676GHz-robust.image.fits'

  exportfits(imagename = myimagebase,
             fitsimage = myfits,
             overwrite = True
             )


  ## and the primary beam files 

  myimagebase = 'VYCMa_sci.spw29_31_33_35_37_39_41_43.cont.I.manual-selfcal-robust.pb.tt0'
  myfits = 'VYCMa_sci.spw29_31_33_35_37_39_41_43.cont.tt0.I.manual-selfcal-robust.pb.fits'

  exportfits(imagename = myimagebase,
             fitsimage = myfits,
             overwrite = True
             )

 

  myimagebase = 'VYCMa_sci.spw33.cube.I.manual-selfcal-H20-658GHz-robust.pb'
  myfits = 'VYCMa_sci.spw33.cube.I.manual-selfcal-H20-658GHz-robust.pb.fits'

  exportfits(imagename = myimagebase,
             fitsimage = myfits,
             overwrite = True
             )

 
  myimagebase = 'VYCMa_sci.spw39.cube.I.manual-selfcal-29SiO-J16-15-676GHz-robust.pb'
  myfits = 'VYCMa_sci.spw39.cube.I.manual-selfcal-29SiO-J16-15-676GHz-robust.pb.fits'

  exportfits(imagename = myimagebase,
             fitsimage = myfits,
             overwrite = True
             )


  

#### END OF FILE
